@@ -12,9 +12,14 @@ from pathlib import Path
 from textwrap import dedent
 from typing import Dict, List, Optional, Tuple, Generator, Any, Iterable
 
-import eodatasets3
 import numpy
 import rasterio
+from rasterio import DatasetReader
+from rasterio.crs import CRS
+from rasterio.enums import Resampling
+from xarray import Dataset
+
+import eodatasets3
 from eodatasets3 import serialise, validate, images, documents
 from eodatasets3.documents import find_and_read_documents
 from eodatasets3.images import FileWrite, GridSpec, MeasurementRecord
@@ -30,10 +35,6 @@ from eodatasets3.model import (
 from eodatasets3.properties import EoFields
 from eodatasets3.validate import Level, ValidationMessage
 from eodatasets3.verify import PackageChecksum
-from rasterio import DatasetReader
-from rasterio.crs import CRS
-from rasterio.enums import Resampling
-from xarray import Dataset
 
 
 class IfExists(Enum):
@@ -80,8 +81,17 @@ class DatasetAssembler(EoFields):
         "landsat:wrs_path",
         "landsat:wrs_row",
         "odc:region_code",
+        "sat:absolute_orbit",
+        "sat:anx_datetime",
+        "sat:orbit_state",
+        "sat:platform_international_designator",
+        "sat:relative_orbit",
+        "sentinel:datastrip_id",
         "sentinel:datatake_start_datetime",
+        "sentinel:grid_square",
+        "sentinel:latitude_band",
         "sentinel:sentinel_tile_id",
+        "sentinel:utm_zone",
     }
 
     def __init__(
@@ -98,12 +108,13 @@ class DatasetAssembler(EoFields):
         """
         Assemble a dataset with ODC metadata, writing metadata and (optionally) its imagery as COGs.
 
-        There are three optional paths that can be specified. At least one must be.
+        There are three optional paths that can be specified. At least one must be specified. Collection,
+        dataset or metadata path.
 
         - A *collection path* is the root folder where datasets will live (in sub-[sub]-folders).
         - Each dataset has its own *dataset location*, as stored in an Open Data Cube index.
-          All paths inside the metadata are relative to this location.
-        - An output metadata document location.
+          All paths inside the metadata document are relative to this location.
+        - An output *metadata document location*.
 
         If you're writing data, you typically only need to specify the collection path, and the others
         will be automatically generated using the naming conventions.
@@ -123,7 +134,7 @@ class DatasetAssembler(EoFields):
             Optional metadata document output path. Otherwise it will be generated according to the collection path
             and naming conventions.
         :param dataset_id:
-            Optional UUID for this dataset, otherwise a random only will be created. Use this if you have a stable
+            Optional UUID for this dataset, otherwise a random one will be created. Use this if you have a stable
             way of generating your own IDs.
         :param if_exists:
             What to do if the output dataset already exists? By default, throw an error.
@@ -378,18 +389,19 @@ class DatasetAssembler(EoFields):
         for name in self.INHERITABLE_PROPERTIES:
             if name not in source_dataset.properties:
                 continue
-            new_val = source_dataset.properties[name]
+            new_value = source_dataset.properties[name]
 
-            existing_val = self.properties.get(name)
-            if existing_val is None:
-                self.properties[name] = new_val
-            else:
-                # Already set. Do nothing.
-                if new_val != existing_val:
-                    warnings.warn(
-                        f"Inheritable property {name!r} is different from current value: "
-                        f"{existing_val!r} != {new_val!r}"
-                    )
+            try:
+                self.properties.normalise_and_set(
+                    name,
+                    new_value,
+                    # If already set, do nothing.
+                    allow_override=False,
+                )
+            except KeyError as k:
+                warnings.warn(
+                    f"Inheritable property {name!r} is different from current value {k.args}"
+                )
 
     def write_measurement(
         self,
@@ -434,7 +446,7 @@ class DatasetAssembler(EoFields):
         file_id=None,
     ):
         """
-        Write a measurement by reading it an open rasterio dataset
+        Write a measurement by reading it from an open rasterio dataset
 
         :param ds: An open rasterio dataset
 
@@ -616,7 +628,7 @@ class DatasetAssembler(EoFields):
                 name,
                 images.GridSpec.from_rio(ds),
                 path,
-                ds.read(1),
+                ds.read(1) if expand_valid_data else None,
                 nodata=ds.nodata,
                 expand_valid_data=expand_valid_data,
             )
@@ -803,6 +815,9 @@ class DatasetAssembler(EoFields):
         return dataset.id, target_metadata_path
 
     def _crs_str(self, crs: CRS) -> str:
+        # TODO: We should support more authorities here.
+        #       if rasterio>=1.1.7, can use crs.to_authority(), but almost
+        #       everyone is currently on 1.1.6
         return f"epsg:{crs.to_epsg()}" if crs.is_epsg_code else crs.to_wkt()
 
     def _document_thumbnail(self, thumb_path, kind=None):
@@ -922,11 +937,16 @@ class DatasetAssembler(EoFields):
 
     def add_accessory_file(self, name: str, path: Path):
         """
-        Record a reference to an additional file. Such as native metadata, thumbnails,
-        checksums, etc. Anything other than ODC measurements.
+        Record a reference to an additional file that's part of the dataset, but is
+        not a band/measurement.
+
+        Such as non-ODC metadata, thumbnails, checksums, etc. Any included file that
+        is not recorded in the measurements.
 
         By convention, the name should have prefixes with their category, such as
-        'metadata:' or 'thumbnail:'
+        'metadata:' or 'thumbnail:'.
+
+        eg. 'metadata:landsat_processor', 'checksum:sha1', 'thumbnail:full'.
 
         :param name: identifying name, eg 'metadata:mtl'
         :param path: local path to file.
