@@ -4,7 +4,9 @@ from abc import ABCMeta, abstractmethod
 from collections import defaultdict
 from datetime import datetime
 from enum import Enum, EnumMeta
+from textwrap import dedent
 from typing import Tuple, Dict, Optional, Any, Mapping, Callable, Union
+from urllib.parse import urlencode
 
 import ciso8601
 from ruamel.yaml.timestamp import TimeStamp as RuamelTimeStamp
@@ -16,6 +18,7 @@ class FileFormat(Enum):
     GeoTIFF = 1
     NetCDF = 2
     Zarr = 3
+    JPEG2000 = 4
 
 
 def nest_properties(d: Mapping[str, Any], separator=":") -> Dict[str, Any]:
@@ -199,10 +202,17 @@ _LANDSAT_EXTENDED_PROPS = {
 _SENTINEL_EXTENDED_PROPS = {
     "sentinel:sentinel_tile_id": parsed_sentinel_tile_id,
     "sentinel:datatake_start_datetime": datetime_type,
+    "sentinel:datastrip_id": None,
+    "sentinel:datatake_type": None,
+    "sentinel:processing_center": None,
+    "sentinel:reception_station": None,
+    "sentinel:utm_zone": int,
+    "sentinel:latitude_band": None,
+    "sentinel:grid_square": None,
 }
 
 
-class StacPropertyView(collections.abc.Mapping):
+class StacPropertyView(collections.abc.MutableMapping):
     # Every property we've seen or dealt with so far. Feel free to expand with abandon...
     # This is to minimise minor typos, case differences, etc, which plagued previous systems.
     # Keep sorted.
@@ -221,6 +231,9 @@ class StacPropertyView(collections.abc.Mapping):
         "eo:constellation": None,
         "eo:sun_azimuth": degrees_type,
         "eo:sun_elevation": degrees_type,
+        "sat:orbit_state": None,
+        "sat:relative_orbit": int,
+        "sat:absolute_orbit": int,
         "landsat:landsat_product_id": None,
         "landsat:landsat_scene_id": None,
         "landsat:wrs_path": int,
@@ -268,13 +281,24 @@ class StacPropertyView(collections.abc.Mapping):
         del self._props[name]
 
     def __setitem__(self, key, value):
-        if key in self._props and value != self[key]:
-            warnings.warn(
-                f"Overriding property {key!r} " f"(from {self[key]!r} to {value!r})"
-            )
+        self.normalise_and_set(
+            key,
+            value,
+            # They can override properties but will receive a warning.
+            allow_override=True,
+        )
 
+    def normalise_and_set(self, key, value, allow_override=True):
+        """
+        Normalise the given value if it's a known key (eg. dates should be dates),
+        and set it on the given dictionary.
+        """
         if key not in self.KNOWN_STAC_PROPERTIES:
-            warnings.warn(f"Unknown stac property {key!r}")
+            warnings.warn(
+                f"Unknown Stac property {key!r}. "
+                f"If this is valid property, please tell us on Github here so we can add it: "
+                f"\n\t{_github_suggest_new_property_url(key, value)}"
+            )
 
         if value is not None:
             normalise = self.KNOWN_STAC_PROPERTIES.get(key)
@@ -288,7 +312,16 @@ class StacPropertyView(collections.abc.Mapping):
                             raise RuntimeError(
                                 f"Infinite loop: writing key {k!r} from itself"
                             )
-                        self[k] = v
+                        self.normalise_and_set(k, v, allow_override=allow_override)
+
+        if key in self._props and value != self[key]:
+            message = (
+                f"Overriding property {key!r} " f"(from {self[key]!r} to {value!r})"
+            )
+            if allow_override:
+                warnings.warn(message)
+            else:
+                raise KeyError(message)
 
         self._props[key] = value
 
@@ -498,3 +531,24 @@ class EoFields(metaclass=ABCMeta):
     @maturity.setter
     def maturity(self, value):
         self.properties["dea:dataset_maturity"] = value
+
+
+def _github_suggest_new_property_url(key: str, value: object) -> str:
+    """Get a URL to create a Github issue suggesting new properties to be added."""
+    issue_parameters = urlencode(
+        dict(
+            title=f"Include property {key!r}",
+            labels="known-properties",
+            body=dedent(
+                f"""\
+                   Hello! The property {key!r} does not appear to be in the KNOWN_STAC_PROPERTIES list,
+                   but I believe it to be valid.
+
+                   An example value of this property is: {value!r}
+
+                   Thank you!
+                   """
+            ),
+        )
+    )
+    return f"https://github.com/GeoscienceAustralia/eo-datasets/issues/new?{issue_parameters}"
