@@ -1,6 +1,7 @@
 import click
 
 from ..prepare.landsat_l1_prepare import main as landsat_l1
+from ..prepare.sentinel_l1c_prepare import main as sentinel_l1c
 from ..prepare.nasa_c_m_mcd43a1_6_prepare import main as mcd43a1
 from ..prepare.noaa_c_c_prwtreatm_1_prepare import main as prwtr
 
@@ -12,6 +13,7 @@ def run():
 
 
 run.add_command(landsat_l1, name="landsat-l1")
+run.add_command(sentinel_l1c, name="sentinel-l1C")
 run.add_command(mcd43a1, name="modis-mcd43a1")
 run.add_command(prwtr, name="noaa-prwtr")
 
