@@ -53,7 +53,7 @@ def read_paths_from_file(listing: Path) -> Iterable[Path]:
             path = Path(loc.strip())
             if not path.exists():
                 raise FileNotFoundError(
-                    "No such file or directory: %s" % (os.path.abspath(loc),)
+                    f"No such file or directory: {os.path.abspath(loc)}"
                 )
 
             yield path.absolute()
@@ -109,9 +109,15 @@ def normalise_band_name(band_name: str) -> str:
     return band_name.lower().replace("-", "_")
 
 
-def get_collection_number(producer: str, usgs_collection_number: int) -> int:
+def get_collection_number(
+    platform: str, producer: str, usgs_collection_number: int
+) -> int:
     # This logic is in one place as it's not very future-proof...
 
+    # We didn't do sentinel before now...
+    if platform.startswith("sentinel"):
+        return 3
+
     if producer == "usgs.gov":
         return usgs_collection_number
     elif producer == "ga.gov.au":
