@@ -164,29 +164,24 @@ def _unpack_observation_attributes(
     product_list: Iterable[str],
     h5group: h5py.Group,
     infer_datetime_range=False,
+    oa_resolution: Optional[Tuple[float, float]] = None,
 ):
     """
     Unpack the angles + other supplementary datasets produced by wagl.
     Currently only the mode resolution group gets extracted.
     """
-    resolution_groups = sorted(g for g in h5group.keys() if g.startswith("RES-GROUP-"))
-    # Use the highest resolution as the ground sample distance.
-    del p.properties["eo:gsd"]
-    p.properties["eo:gsd"] = min(
-        min(h5group[grp].attrs["resolution"]) for grp in resolution_groups
-    )
+    resolution_groups = {
+        tuple(h5group[k].attrs["resolution"]): h5group[k]
+        for k in h5group.keys()
+        if k.startswith("RES-GROUP-")
+    }
 
-    if len(resolution_groups) not in (1, 2):
-        raise NotImplementedError(
-            f"Unexpected set of res-groups. "
-            f"Expected either two (with pan) or one (without pan), "
-            f"got {resolution_groups!r}"
-        )
-    # Res groups are ordered in descending resolution, so res-group-0 is the highest resolution.
-    # (ie. res-group-0 in landsat 7/8 is Panchromatic)
-    # We only care about packaging OA data for the "common" bands: not panchromatic.
-    # So we always pick the lowest resolution: the last (or only) group.
-    res_grp = h5group[resolution_groups[-1]]
+    # Use the highest resolution as the ground sample distance.
+    if "eo:gsd" in p.properties:
+        del p.properties["eo:gsd"]
+    p.properties["eo:gsd"] = min(min(resolution_groups.keys()))
+
+    res_grp = choose_resolution_group(resolution_groups, p.platform, oa_resolution)
 
     def _write(section: str, dataset_names: Sequence[str]):
         """
@@ -234,6 +229,36 @@ def _unpack_observation_attributes(
         )
 
 
+def choose_resolution_group(
+    resolution_groups: Dict[tuple, h5py.Group],
+    platform: str,
+    oa_resolution=Optional[Tuple[float, float]],
+) -> h5py.Group:
+
+    # None specified? Figure out a default.
+
+    if oa_resolution is None:
+        # For Landsat, we only cared about packaging OA data for the "common"
+        # bands (not panchromatic). So we always pick the higher resolution.
+        if platform.startswith("landsat"):
+            oa_resolution = max(resolution_groups.keys())
+        elif platform.startswith("sentinel"):
+            oa_resolution = (20.0, 20.0)
+        else:
+            raise NotImplementedError(
+                f"Don't know how to choose a default OA resolution for platform {platform !r}"
+            )
+
+    res_grp = resolution_groups.get(oa_resolution)
+    if res_grp is None:
+        raise RuntimeError(
+            f"Resolution {oa_resolution} not found in input. "
+            f"Have resolutions {tuple(resolution_groups.keys())}"
+        )
+
+    return res_grp
+
+
 def _create_contiguity(
     p: DatasetAssembler,
     product_list: Iterable[str],
@@ -350,7 +375,7 @@ class Granule:
     name: str
     wagl_hdf5: Path
     wagl_metadata: Dict
-    source_level1_metadata: DatasetDoc
+    source_level1_metadata: Optional[DatasetDoc]
 
     fmask_doc: Optional[Dict] = None
     fmask_image: Optional[Path] = None
@@ -399,15 +424,20 @@ class Granule:
                     level1_tar_path = Path(
                         get_path(wagl_doc, ("source_datasets", "source_level1"))
                     )
-                    level1_metadata_path = level1_tar_path.with_suffix(
-                        ".odc-metadata.yaml"
-                    )
-                if not level1_metadata_path.exists():
+                    if level1_tar_path.exists():
+                        level1_metadata_path = level1_tar_path.with_suffix(
+                            ".odc-metadata.yaml"
+                        )
+                if level1_metadata_path and not level1_metadata_path.exists():
                     raise ValueError(
                         f"No level1 metadata found at {level1_metadata_path}"
                     )
 
-                level1 = serialise.from_path(level1_metadata_path)
+                level1 = (
+                    serialise.from_path(level1_metadata_path)
+                    if level1_metadata_path
+                    else None
+                )
 
                 fmask_image_path = fmask_image_path or wagl_hdf5.with_name(
                     f"{granule_name}.fmask.img"
@@ -486,6 +516,7 @@ def package(
     granule: Granule,
     included_products: Iterable[str] = DEFAULT_PRODUCTS,
     include_oa: bool = True,
+    oa_resolution=Optional[Tuple[float, float]],
 ) -> Tuple[UUID, Path]:
     """
     Package an L2 product.
@@ -512,22 +543,44 @@ def package(
         granule_group = fid[granule.name]
 
         with DatasetAssembler(
-            out_directory,
+            out_directory.absolute(),
             # WAGL stamps a good, random ID already.
             dataset_id=granule.wagl_metadata.get("id"),
+            # naming_conventions="dea_s2" if ('sentinel' in p.platform) else "dea",
             naming_conventions="dea",
         ) as p:
-            level1 = granule.source_level1_metadata
-            p.add_source_dataset(level1, auto_inherit_properties=True)
+            wagl_doc = _apply_wagl_metadata(p, granule_group)
 
             # It's a GA ARD product.
             p.producer = "ga.gov.au"
             p.product_family = "ard"
+            p.maturity = _determine_maturity(
+                acq_date=p.datetime,
+                processed=p.processed,
+                wagl_doc=wagl_doc,
+            )
+            if granule.source_level1_metadata is not None:
+                # For historical consistency: we want to use the instrument that the source L1 product
+                # came from, not the instruments reported from the WAGL doc.
+                #
+                # Eg.
+                #     Level 1 will say "OLI_TIRS", while wagl doc will say "OLI".
+                #     Our current C3 products say "OLI_TIRS" so we need to stay consistent.
+                #     (even though WAGL only *used* the OLI bands, it came from an OLI_TIRS observation)
+                #
+                # So delete our current wagl one, since we're adding a source dataset:
+                if p.instrument is not None:
+                    del p.properties["eo:instrument"]
 
-            _read_wagl_metadata(p, granule_group)
+                p.add_source_dataset(
+                    granule.source_level1_metadata, auto_inherit_properties=True
+                )
+                # When level 1 is NRT, ARD is always NRT.
+                if granule.source_level1_metadata.maturity == "nrt":
+                    p.maturity = "nrt"
 
             org_collection_number = utils.get_collection_number(
-                p.producer, p.properties["landsat:collection_number"]
+                p.platform, p.producer, p.properties.get("landsat:collection_number")
             )
 
             p.dataset_version = f"{org_collection_number}.2.0"
@@ -546,7 +599,8 @@ def package(
                         p,
                         included_products,
                         granule_group,
-                        infer_datetime_range=level1.platform.startswith("landsat"),
+                        infer_datetime_range=p.platform.startswith("landsat"),
+                        oa_resolution=oa_resolution,
                     )
                 if granule.fmask_image:
                     with do(f"Writing fmask from {granule.fmask_image} "):
@@ -589,7 +643,8 @@ def _read_fmask_doc(p: DatasetAssembler, doc: Dict):
     for name, value in doc["percent_class_distribution"].items():
         # From Josh: fmask cloud cover trumps the L1 cloud cover.
         if name == "cloud":
-            del p.properties["eo:cloud_cover"]
+            if "eo:cloud_cover" in p.properties:
+                del p.properties["eo:cloud_cover"]
             p.properties["eo:cloud_cover"] = value
 
         p.properties[f"fmask:{name}"] = value
@@ -611,20 +666,22 @@ def find_a_granule_name(wagl_hdf5: Path) -> str:
 
     >>> find_a_granule_name(Path('LT50910841993188ASA00.wagl.h5'))
     'LT50910841993188ASA00'
+    >>> find_a_granule_name(Path('S2A_OPER_MSI_L1C_TL_EPAE_20201031T022859_A027984_T53JQJ_N02.09.wagl.h5'))
+    'S2A_OPER_MSI_L1C_TL_EPAE_20201031T022859_A027984_T53JQJ_N02.09'
     >>> find_a_granule_name(Path('my-test-granule.h5'))
     Traceback (most recent call last):
     ...
-    ValueError: No granule specified, and cannot find it on input filename 'my-test-granule'.
+    ValueError: Does not appear to be a wagl output filename? 'my-test-granule.h5'.
     """
-    granule_name = wagl_hdf5.stem.split(".")[0]
-    if not granule_name.startswith("L"):
+    if not wagl_hdf5.name.endswith(".wagl.h5"):
         raise ValueError(
-            f"No granule specified, and cannot find it on input filename {wagl_hdf5.stem!r}."
+            f"Does not appear to be a wagl output filename? {wagl_hdf5.name!r}."
         )
-    return granule_name
+
+    return wagl_hdf5.name[: -len(".wagl.h5")]
 
 
-def _read_wagl_metadata(p: DatasetAssembler, granule_group: h5py.Group):
+def _apply_wagl_metadata(p: DatasetAssembler, granule_group: h5py.Group) -> Dict:
     try:
         wagl_path, *ancil_paths = [
             pth
@@ -636,6 +693,11 @@ def _read_wagl_metadata(p: DatasetAssembler, granule_group: h5py.Group):
 
     [wagl_doc] = loads_yaml(granule_group[wagl_path][()])
 
+    source = wagl_doc["source_datasets"]
+    p.datetime = source["acquisition_datetime"]
+    p.platform = source["platform_id"]
+    p.instrument = source["sensor_id"]
+
     try:
         p.processed = get_path(wagl_doc, ("system_information", "time_processed"))
     except PathAccessError:
@@ -646,12 +708,9 @@ def _read_wagl_metadata(p: DatasetAssembler, granule_group: h5py.Group):
             list(loads_yaml(granule_group[path][()]))[0]["ancillary"]
         )
 
-    p.properties["dea:dataset_maturity"] = _determine_maturity(
-        p.datetime, p.processed, wagl_doc
-    )
-
     _take_software_versions(p, wagl_doc)
     p.extend_user_metadata("wagl", wagl_doc)
+    return wagl_doc
 
 
 def _determine_maturity(acq_date: datetime, processed: datetime, wagl_doc: Dict):
@@ -660,6 +719,7 @@ def _determine_maturity(acq_date: datetime, processed: datetime, wagl_doc: Dict)
 
     Based on the fallback logic in nbar pages of CMI, eg: https://cmi.ga.gov.au/ga_ls5t_nbart_3
     """
+
     ancillary_tiers = {
         key.lower(): o["tier"]
         for key, o in wagl_doc["ancillary"].items()
